pub(crate) struct PipelineData<'a> {
stage: PipelineStage,
_writer: StandardStream,
_config: Config,
diagnostics_enabled: bool,
errors_emitted: usize,
pub files: SimpleFiles<&'a str, &'a str>,
current_file: usize,
pub syntax_trees: Vec<Root>,
pub dc_data: DCData,
}Expand description
Data stored in memory throughout the DC parser pipeline.
Sets up writer and codespan config for rendering diagnostics to stderr & storing DC files that implement codespan’s File trait.
Fields
stage: PipelineStage_writer: StandardStream_config: Configdiagnostics_enabled: boolerrors_emitted: usizefiles: SimpleFiles<&'a str, &'a str>current_file: usizesyntax_trees: Vec<Root>dc_data: DCDataImplementations
Sourceimpl PipelineData<'_>
impl PipelineData<'_>
Sourcepub(crate) fn emit_diagnostic(
&mut self,
diag: Diagnostic<usize>,
) -> Result<(), Error>
pub(crate) fn emit_diagnostic( &mut self, diag: Diagnostic<usize>, ) -> Result<(), Error>
Thin wrapper for emitting a codespan diagnostic using PipelineData properties.
pub(crate) fn current_stage(&self) -> PipelineStage
pub(crate) fn next_stage(&mut self)
pub(crate) fn current_file(&self) -> usize
pub(crate) fn next_file(&mut self)
pub(crate) fn failing(&self) -> bool